@@ -633,7 +633,7 @@ class LaharFlowData(object):
                 filetype = 'MaxSpeeds.txt'
             elif filename=='InundationTime.txt':
                 filetype = 'InundationTime.txt'
-            if filename=='Maximums.nc':
+            elif filename=='Maximums.nc':
                 filetype = 'Maximums.nc'
             else:
                 filetype = 'snapshot'
@@ -1527,6 +1527,9 @@ class LaharFlowData(object):
             cax = divider.append_axes("right", size="5%", pad=0.05)
 
         cbar = plt.colorbar(im, cax=cax, orientation=orientation)
+        ct = cbar.get_ticks()
+        ct = np.insert(ct, 0, vmin)
+        cbar.set_ticks(ct)
         cbar.ax.set_ylabel(fmt['short_name'].replace('_',' ')
                             + ' ({unit})'.format(unit=fmt['units']))
 
