@@ -1,6 +1,6 @@
 import netCDF4 as nc
 import numpy as np
-
+from numpy.lib.recfunctions import rename_fields as np_rename_fields
 
 def nc2np(filename, var=None):
 
@@ -12,8 +12,13 @@ def nc2np(filename, var=None):
         nc_variables = list(rgrp[tiles[0]].variables)
 
         if var is not None:
-            if var not in nc_variables:
-                raise ValueError('variable {} not in netcdf file {}'.format(var, filename))
+            if isinstance(var, list):
+                for v in var:
+                    if v not in nc_variables:
+                        raise ValueError('variable {} not in netcdf file {}'.format(v, filename))
+            else:
+                if var not in nc_variables:
+                    raise ValueError('variable {} not in netcdf file {}'.format(var, filename))
 
         nX = attrs['nXpertile']
         nY = attrs['nYpertile']
@@ -23,21 +28,38 @@ def nc2np(filename, var=None):
         if var is None:
             variables = nc_variables.copy()
         else:
-            variables = ['x_distance', 'y_distance', var]
+            variables = []
+            if 'x_distance' in nc_variables:
+                variables.append('x_distance')
+            if 'x' in nc_variables:
+                variables.append('x')
+            if 'y_distance' in nc_variables:
+                variables.append('y_distance')
+            if 'y' in nc_variables:
+                variables.append('y')
+            if 'lat' in nc_variables:
+                variables.append('lat')
+            if 'latitude' in nc_variables:
+                variables.append('latitude')
+            if 'lon' in nc_variables:
+                variables.append('lon')
+            if 'longitude' in nc_variables:
+                variables.append('longitude')
+            if isinstance(var, list):
+                for v in var:
+                    variables.append(v)
+            else:
+                variables.append(var)
 
         dt = [('tile',int)]
         for v in variables:
-            if v=='x':
-                vname = 'x_distance'
-            elif v=='y':
-                vname = 'y_distance'
-            else:
-                vname = v
-            dt.append((vname, rgrp[tiles[0]][v].dtype))
+            dt.append((v, rgrp[tiles[0]][v].dtype))
 
-        data = np.empty((nrows,), dtype=dt)
+        data = np.full((nrows,), np.nan, dtype=dt)
+
+        data = np_rename_fields(data, {'x':'x_distance', 'y':'y_distance'})
         
-        #data[:] = np.nan
+        # data[:] = np.nan
 
         if 'x' in variables:
             variables.remove('x')
